@@ -4,14 +4,12 @@
 # Use, reproduction, transfer, publication or disclosure is prohibited except
 # as specifically provided for in your License Agreement with Software AG.
 
-# pylint: disable=too-many-lines
-
 from invoke import task
 from setuptools_scm import get_version
 
 
 @task
-def version(c):
+def show_version(_):
     """Print the module version.
 
     This version string is infered from the last Git tag. A tagged HEAD
@@ -38,3 +36,20 @@ def build(c):
     This will create a distributable wheel (.whl) file.
     """
     c.run('python -m build')
+
+
+@task(help={
+    'sample': "Which sample to build.",
+    "version": "Microservice version. Defaults to '1.0.0'.",
+})
+def build_ms(c, sample, version='1.0.0'):
+    """Build a Cumulocity micro service.
+
+    This will build a ready to deploy Cumulocity micro service from a sample
+    file within the `samples` folder. Any sample Python script can be used
+    (if it implements micro service logic).
+
+    Use the file name without .py extension as name. The build microservice
+    will use a similar name, following Cumulocity naming guidelines.
+    """
+    c.run(f'samples/build.sh {sample} {version}')
